Skip to main contentModule engine
Source - EngineConfig
- Configuration for the pyramid generation engine.
- EngineResult
- Summary statistics returned after a successful pyramid generation.
- StageDurations
- Per-stage duration breakdown for a single pyramid run.
- BlankTileStrategy
- Controls how blank (uniform-color) tiles are handled during pyramid generation.
- EngineError
- Errors that can occur during pyramid generation.
- is_blank_tile
- Returns
true if every pixel in the tile is identical (i.e. the tile is
a uniform solid color). - is_blank_tile_with_tolerance
- Returns
true if every pixel in the tile is within max_channel_delta
of the tile’s first pixel on every channel.